@@ -118,7 +118,7 @@ static gboolean get_xrandr_info()
         return FALSE;
     }
 
-    regex = g_regex_new( "\n([-a-zA-Z]+[-0-9]*) +connected ([^(\n ]*)[^\n]*"
+    regex = g_regex_new( "\n([-\\.a-zA-Z]+[-\\.0-9]*) +connected ([^(\n ]*)[^\n]*"
                          "((\n +[0-9]+x[0-9]+[^\n]+)+)",
                          0, 0, NULL );
     if( g_regex_match( regex, output, 0, &match ) )
@@ -213,6 +213,12 @@ static gboolean get_xrandr_info()
     setlocale( LC_ALL, ori_locale );
     g_free( ori_locale );
 
+    // Handle the case actually no monitor is added
+    if (! monitors)
+    {
+        return FALSE;
+    }
+
     return TRUE;
 }
 
